Crate wayapp

Crate wayapp 

Structs

Application
DispatchToken
EguiSurfaceState
Surface-specific EGUI state
EguiWgpuRenderer
EguiWgpuRendererThread
SingleColorState
WaylandEventEmitter
External dispatcher for emitting Wayland events from outside the application
WaylandToEguiInput
Handles input events from Wayland and converts them to EGUI RawInput

Enums

Kind
WaylandEvent
Enum representing different Wayland events

Traits

OptionEguiSurfaceStateExt
Helper trait to allow calling contains on Option<EguiSurfaceState<T>>

Functions

egui_to_cursor_shape